Summarize log-transformed continuous variable
Source:R/AutoScript.summary.R
AS.summary.loglinear.RdComputes a string with the geometric mean and standard deviation in the form
"geometric mean ± SD".
R/AutoScript.summary.R
AS.summary.loglinear.RdComputes a string with the geometric mean and standard deviation in the form
"geometric mean ± SD".